Package: metadat
Version: 1.2-0
Date: 2022-04-05
Title: Meta-Analysis Datasets
Authors@R: c(
  person(given = "Thomas", family="White",
  role="aut", email = "thomas.white@sydney.edu.au",
  comment = c(ORCID = "0000-0002-3976-1734")),
  person(given = "Daniel", family="Noble",
  role="aut", email = "daniel.noble@anu.edu.au",
  comment = c(ORCID = "0000-0001-9460-8743")),
  person(given = "Alistair", family="Senior",
  role="aut", email = "alistair.senior@sydney.edu.au",
  comment = c(ORCID = "0000-0001-9805-7280")),
  person(given = "W. Kyle", family="Hamilton",
  role="aut", email = "whamilton@ucmerced.edu",
  comment = c(ORCID = "0000-0002-8642-7990")),
  person(given = "Wolfgang", family = "Viechtbauer",
  role = c("aut","cre"), email = "wvb@metafor-project.org",
  comment = c(ORCID = "0000-0003-3463-4063")),
  person(given = "Guido", family = "Schwarzer",
  role = "dtc", email = "sc@imbi.uni-freiburg.de",
  comment = c(ORCID = "0000-0001-6214-9087")))
Depends: R (>= 4.0.0)
Imports: utils, tools, mathjaxr
Suggests: metafor, numDeriv, BiasedUrn, dfoptim, igraph, ape, testthat,
        digest, lme4, clubSandwich, meta, netmeta, mvtnorm, gridExtra,
        rms
Description: A collection of meta-analysis datasets for teaching purposes, illustrating/testing meta-analytic methods, and validating published analyses.
License: GPL (>=2)
ByteCompile: TRUE
LazyData: TRUE
Encoding: UTF-8
RdMacros: mathjaxr
URL: https://github.com/wviechtb/metadat
BugReports: https://github.com/wviechtb/metadat/issues
Author: Thomas White [aut] (<https://orcid.org/0000-0002-3976-1734>),
  Daniel Noble [aut] (<https://orcid.org/0000-0001-9460-8743>),
  Alistair Senior [aut] (<https://orcid.org/0000-0001-9805-7280>),
  W. Kyle Hamilton [aut] (<https://orcid.org/0000-0002-8642-7990>),
  Wolfgang Viechtbauer [aut, cre]
    (<https://orcid.org/0000-0003-3463-4063>),
  Guido Schwarzer [dtc] (<https://orcid.org/0000-0001-6214-9087>)
Maintainer: Wolfgang Viechtbauer <wvb@metafor-project.org>
Built: R 4.4.0; ; 2024-04-29 10:07:15 UTC; unix
